..
    Copyright (C) 2022 CERN.

    Invenio-RDM-Migrator is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.


.. include:: ../README.rst

User's Guide
------------

This part of the documentation will show you how to get started in using
Invenio-RDM-Migrator.

.. toctree::
   :maxdepth: 2

   installation
   usage

Additional Notes
----------------

Notes on how to contribute, legal information and changes are here for the
interested.

.. toctree::
   :maxdepth: 1

   contributing
   changes
   license
   authors
